Crate lexe_api

Crate lexe_api 

Crate containing Lexe API types, definitions, client/server utils, TLS.

Modules

auth
Bearer auth and User Signup.
axum_helpers
Make all of lexe_api_core available under [lexe_api].
cli
Make all of lexe_api_core available under [lexe_api].
def
Make all of lexe_api_core available under [lexe_api].
error
Make all of lexe_api_core available under [lexe_api].
macros
Make all of lexe_api_core available under [lexe_api].
models
Make all of lexe_api_core available under [lexe_api].
rest
A client and helpers that enforce common REST semantics across Lexe crates.
server
Webserver utilities. This module provides various API server utilities.
trace
API tracing utilities for both client and server. This module provides API tracing utilities for both client and server, including constants and fns which help keep client and server consistent.
types
Make all of lexe_api_core available under [lexe_api].
vfs
Make all of lexe_api_core available under [lexe_api].

Macros

api_error
Make all of lexe_api_core available under [lexe_api].
api_error_kind
Make all of lexe_api_core available under [lexe_api].
define_trace_id_fns
Generates implementations of the functions pointed to by GET_TRACE_ID_FN and INSERT_TRACE_ID_FN given the type of the tracing::Subscriber. The caller (typically lexe_logger::try_init()) is responsible for initializing these statics using the generated implementations.
user_agent_to_external
Make all of lexe_api_core available under [lexe_api].
user_agent_to_lexe
Make all of lexe_api_core available under [lexe_api].