pub fn token_needs_refresh(
now: SystemTime,
expiration: Option<SystemTime>,
) -> boolExpand description
Returns true if we should refresh the token (i.e., it’s expired or about
to expire).
pub fn token_needs_refresh(
now: SystemTime,
expiration: Option<SystemTime>,
) -> boolReturns true if we should refresh the token (i.e., it’s expired or about
to expire).