Make all of lexe_api_core available under [lexe_api].
NOTE: Any crates which can depend on lexe_api_core directly (without
lexe-api) should do so to avoid [lexe_api] dependencies.
Enclave CLI args and types.
Modules
- node
- User node CLI args.
Structs
- LspFees
- Information about Lexe’s LSP’s fees.
- LspInfo
- Information about the LSP which the user node needs to connect and to generate route hints when no channel exists.
- OAuth
Config - Configuration info relating to Google OAuth2. When combined with an auth
code, can be used to obtain a GDrive access token and refresh token.
Traits
- Enclave
Args - A trait for the arguments to an enclave command.