pub struct LspInfo {
pub node_pk: NodePk,
pub private_p2p_addr: LxSocketAddress,
pub lsp_usernode_base_fee_msat: u32,
pub lsp_usernode_prop_fee_ppm: u32,
pub lsp_external_prop_fee_ppm: u32,
pub lsp_external_base_fee_msat: u32,
pub cltv_expiry_delta: u16,
pub htlc_minimum_msat: u64,
pub htlc_maximum_msat: u64,
}Expand description
Information about the LSP which the user node needs to connect and to generate route hints when no channel exists.
Fields
node_pk: NodePkprivate_p2p_addr: LxSocketAddressThe socket on which the LSP accepts P2P LN connections from user nodes
lsp_usernode_base_fee_msat: u32LSP’s configured base fee for forwarding over LSP -> User channels.
- For inbound payments, this fee is encoded in the invoice route hints
(as part of the
RoutingFeesstruct) - Also used to estimate how much can be sent to another Lexe user.
lsp_usernode_prop_fee_ppm: u32LSP’s configured prop fee for forwarding over LSP -> User channels.
- For inbound payments, this fee is encoded in the invoice route hints
(as part of the
RoutingFeesstruct) - Also used to estimate how much can be sent to another Lexe user.
lsp_external_prop_fee_ppm: u32LSP’s configured prop fee for forwarding over LSP -> External channels.
lsp_external_base_fee_msat: u32LSP’s configured base fee for forwarding over LSP -> External channels.
cltv_expiry_delta: u16htlc_minimum_msat: u64htlc_maximum_msat: u64Implementations