BackendErrorKind

Enum BackendErrorKind 

pub enum BackendErrorKind {
Show 20 variants Unknown(u16), UnknownReqwest, Building, Connect, Timeout, Decode, Server, Rejection, AtCapacity, Database, NotFound, Duplicate, Conversion, Unauthenticated, Unauthorized, AuthExpired, InvalidParsedRequest, BatchSizeOverLimit, NotUpdatable, ClientUpgradeRequired,
}
All variants of errors that the backend can return.

Variants



Unknown(u16)

Unknown error



UnknownReqwest

Unknown Reqwest client error



Building

Error building the HTTP request



Connect

Error connecting to a remote HTTP service



Timeout

Request timed out



Decode

Error decoding/deserializing the HTTP response body



Server

General server error



Rejection

Client provided a bad request that the server rejected



AtCapacity

Server is at capacity



Database

Database error



NotFound

Resource not found



Duplicate

Resource was duplicate



Conversion

Could not convert field or model to type



Unauthenticated

User failed authentication



Unauthorized

User not authorized



AuthExpired

Auth token or auth request is expired



InvalidParsedRequest

Parsed request is invalid



BatchSizeOverLimit

Request batch size is over the limit



NotUpdatable

Resource is not updatable



ClientUpgradeRequired

Client is too old to handle the response; upgrade required