MegaErrorKind

Enum MegaErrorKind 

pub enum MegaErrorKind {
    Unknown(u16),
    UnknownReqwest,
    Building,
    Connect,
    Timeout,
    Decode,
    Server,
    Rejection,
    AtCapacity,
    WrongMegaId,
    RunnerUnreachable,
    UnknownUser,
}
All variants of errors that the LSP can return.

Variants



Unknown(u16)

Unknown error



UnknownReqwest

Unknown Reqwest client error



Building

Error building the HTTP request



Connect

Error connecting to a remote HTTP service



Timeout

Request timed out



Decode

Error decoding/deserializing the HTTP response body



Server

General server error



Rejection

Client provided a bad request that the server rejected



AtCapacity

Server is at capacity



WrongMegaId

Request mega_id doesn’t match current mega_id



RunnerUnreachable

Usernode runner is currently unreachable; try again later



UnknownUser

The requested user is not known to this meganode