pub enum NodeErrorKind {
Show 17 variants
Unknown(u16),
UnknownReqwest,
Building,
Connect,
Timeout,
Decode,
Server,
Rejection,
AtCapacity,
WrongUserPk,
WrongNodePk,
WrongMeasurement,
Provision,
BadAuth,
Proxy,
Command,
NotFound,
}Expand description
All variants of errors that the node can return.
Variants
Unknown(u16)
Unknown error
UnknownReqwest
Unknown Reqwest client error
Building
Error building the HTTP request
Connect
Error connecting to a remote HTTP service
Timeout
Request timed out
Decode
Error decoding/deserializing the HTTP response body
Server
General server error
Rejection
Client provided a bad request that the server rejected
AtCapacity
Server is at capacity
WrongUserPk
Wrong user pk
WrongNodePk
Given node pk doesn’t match node pk derived from seed
WrongMeasurement
Request measurement doesn’t match current enclave measurement
Provision
Error occurred during provisioning
BadAuth
Authentication error
Proxy
Could not proxy request to node
Command
Error
NotFound
Resource not found