RunnerErrorKind

Enum RunnerErrorKind 

pub enum RunnerErrorKind {
Show 19 variants Unknown(u16), UnknownReqwest, Building, Connect, Timeout, Decode, Server, Rejection, AtCapacity, Runner, UnknownMeasurement, OldVersion, TemporarilyUnavailable, ServiceUnavailable, Boot, EvictionFailure, UnknownUser, LeaseExpired, WrongLease,
}
All variants of errors that the runner can return.

Variants



Unknown(u16)

Unknown error



UnknownReqwest

Unknown Reqwest client error



Building

Error building the HTTP request



Connect

Error connecting to a remote HTTP service



Timeout

Request timed out



Decode

Error decoding/deserializing the HTTP response body



Server

General server error



Rejection

Client provided a bad request that the server rejected



AtCapacity

Server is at capacity



Runner

General Runner error



UnknownMeasurement

Unknown or unserviceable measurement



OldVersion

Caller requested a version which is too old



TemporarilyUnavailable

Requested node temporarily unavailable, most likely due to a common race condition; retry the request (temporary error)



ServiceUnavailable

Runner service is unavailable (semi-permanent error)



Boot

Requested node failed to boot



EvictionFailure

Failed to evict a usernode



UnknownUser

The requested user is not known to the runner



LeaseExpired

Tried to renew a lease that has already expired



WrongLease

Tried to renew a lease belonging to a different user