api_error

Macro api_error 

macro_rules! api_error {
    ($api_error:ident, $api_error_kind:ident) => { ... };
}
Make all of lexe_api_core available under [lexe_api].

NOTE: Any crates which can depend on lexe_api_core directly (without lexe-api) should do so to avoid [lexe_api] dependencies. This macro takes the name of an ApiError and its error kind type to generate the various impls required by the ApiError trait alias.

This macro should be used in combination with api_error_kind! below.

api_error!(FooApiError, FooErrorKind);