CreateOfferRequest

Struct CreateOfferRequest 

pub struct CreateOfferRequest {
    pub description: Option<BoundedString>,
    pub min_amount: Option<Amount>,
    pub expiry_secs: Option<u32>,
    pub max_quantity: Option<MaxQuantity>,
    pub issuer: Option<BoundedString>,
}

Fields

description: Option<BoundedString>

The description to be encoded into the invoice.

If None, the description field inside the invoice will be an empty string (“”), as lightning requires a description to be set.

min_amount: Option<Amount>

The min_amount we’re requesting for payments using this offer.

If None, the offer is variable amount and the payer can choose any value.

If Some, the offer amount is lower-bounded and the payer must pay this value or higher (per item, see max_quantity). The offer amount must be a non-zero value if set.

expiry_secs: Option<u32>

An optional expiration for the offer, in seconds from now.

max_quantity: Option<MaxQuantity>

The max number of items that can be purchased in any one payment for the offer.

NOTE: this is not related to single-use vs reusable offers.

The expected amount paid for this offer is offer.min_amount * quantity, where offer.min_amount is the value per item and quantity is the number of items chosen by the payer. The payer’s chosen quantity must be in the range: 0 < quantity <= offer.max_quantity.

If None, defaults to MaxQuantity::ONE, i.e., the expected paid amount is just offer.amount.

issuer: Option<BoundedString>

The issuer of the offer.

If Some, offer will encode the string. Bolt12 spec expects this tring to be a domain or a user@domain address. If None, offer issuer will encode “lexe.app” as the issuer.