pub struct GetNewPayments {
pub start_index: Option<PaymentCreatedIndex>,
pub limit: Option<u16>,
}Expand description
Sync a batch of new payments to local storage.
Results are returned in ascending (created_at, payment_id) order.
Fields
start_index: Option<PaymentCreatedIndex>Optional PaymentCreatedIndex at which the results should start,
exclusive. Payments with an index less than or equal to this will
not be returned.
limit: Option<u16>(Optional) the maximum number of results that can be returned.