pub struct GetUpdatedPaymentMetadata {
pub start_index: Option<PaymentUpdatedIndex>,
pub limit: Option<u16>,
}Expand description
Get a batch of payment metadata in asc (updated_at, payment_id) order.
Fields
start_index: Option<PaymentUpdatedIndex>(updated_at, id) index at which the results should start, exclusive.
Metadata with an index less than or equal to this will not be returned.
limit: Option<u16>(Optional) the maximum number of results that can be returned.