pub struct PayInvoicePreflightResponse {
pub amount: Amount,
pub fees: Amount,
pub route: LxRoute,
pub ldk_route: Vec<u8>,
}Fields
amount: AmountThe total amount to-be-paid for the pre-flighted Invoice,
excluding the fees.
This value may be different from the value originally requested if
we had to reach htlc_minimum_msat for some intermediate hops.
fees: AmountThe total amount of fees to-be-paid for the pre-flighted Invoice.
route: LxRouteThe route used in the preflight, to be used for informational purposes.
See ldk_route for how to pay the invoice along this route.
ldk_route: Vec<u8>A precomputed route that the caller should pass into
PayInvoiceRequest to ensure that:
- The preflighted fee that the user sees is actually what they pay
pay_invoicedoesn’t need to recompute the route, saving time and compute.