pub struct PayOfferRequest {
pub cid: ClientPaymentId,
pub offer: Offer,
pub fallback_amount: Option<Amount>,
pub note: Option<BoundedNote>,
pub payer_note: Option<BoundedNote>,
}Fields
cid: ClientPaymentIdThe user-provided idempotency id for this payment.
offer: OfferThe offer we want to pay.
fallback_amount: Option<Amount>Specifies the amount we will pay if the offer to be paid is
amountless. This field must be Some for amountless offers.
note: Option<BoundedNote>An optional personal note for this payment, useful if the receiver-provided description is insufficient.
payer_note: Option<BoundedNote>An optional note included in the BOLT12 invoice request and visible to the recipient.