pub struct PayOnchainRequest {
pub cid: ClientPaymentId,
pub address: Address<NetworkUnchecked>,
pub amount: Amount,
pub priority: ConfirmationPriority,
pub note: Option<BoundedNote>,
}Fields
cid: ClientPaymentIdThe identifier to use for this payment.
address: Address<NetworkUnchecked>The address we want to send funds to.
amount: AmountHow much Bitcoin we want to send.
priority: ConfirmationPriorityHow quickly we want our transaction to be confirmed. The higher the priority, the more fees we will pay.
note: Option<BoundedNote>An optional personal note for this payment.