PreflightPayOfferResponse

Struct PreflightPayOfferResponse 

pub struct PreflightPayOfferResponse {
    pub amount: Amount,
    pub fees: Amount,
    pub route: LxRoute,
}

Fields

amount: Amount

The total amount to-be-paid for the pre-flighted Offer, excluding the fees.

This value may be different from the value originally requested if we had to reach htlc_minimum_msat for some intermediate hops.

fees: Amount

The total amount of fees to-be-paid for the pre-flighted Offer.

Since we only approximate the route atm, we likely underestimate the actual fee.

route: LxRoute

The route this offer will be paid over.

Because we don’t yet fetch the actual BOLT 12 invoice during preflight, this route is only an approximation of the final route (we can only route to the last public node before the offer’s blinded path begins).