PreflightCloseChannelRequest

Type Alias PreflightCloseChannelRequest 

pub type PreflightCloseChannelRequest = CloseChannelRequest;

Aliased Type

pub struct PreflightCloseChannelRequest {
    pub channel_id: LxChannelId,
    pub force_close: bool,
    pub maybe_counterparty: Option<NodePk>,
}

Fields

channel_id: LxChannelId

The id of the channel we want to close.

force_close: bool

Set to true if the channel should be force closed (unilateral). Set to false if the channel should be cooperatively closed (bilateral).

maybe_counterparty: Option<NodePk>

The NodePk of our counterparty.

If set to None, the counterparty’s NodePk will be determined by calling list_channels. Setting this to Some allows close_channel to avoid this relatively expensive Vec allocation.