Module revocable_clients

Module revocable_clients 

Make all of lexe_api_core available under [lexe_api].

NOTE: Any crates which can depend on lexe_api_core directly (without lexe-api) should do so to avoid [lexe_api] dependencies. Revocable client API types and RevocableClients. Information about a client

Modules

models
Request and response types for the revocable client endpoints. Request and response types for the revocable client endpoints.

Structs

RevocableClient
Information about a revocable client. Each client is issued a RevocableClientCert whose pubkey is saved here.
RevocableClients
All revocable clients which have ever been created.
RevocableClientsHandle
A locked RevocableClients, newtyped so it can implement GetRevocableClientStatus. Share via Arc<RevocableClientsHandle>.