Module models

Module models 

Request and response types for the revocable client endpoints. Request and response types for the revocable client endpoints.

Structs

CreateRevocableClientRequest
A request to create a new revocable client.
CreateRevocableClientResponse
The response to CreateRevocableClientRequest.
ListRevocableClients
A request to list all revocable clients.
UpdateClientRequest
A request to update a single RevocableClient.
UpdateClientResponse
The updated RevocableClient after a successful update.