spawn_server_task

Function spawn_server_task 

pub fn spawn_server_task(
    bind_addr: SocketAddr,
    router: Router<()>,
    layer_config: LayerConfig,
    maybe_tls_and_dns: Option<(Arc<ServerConfig>, &str)>,
    server_span_name: Cow<'static, str>,
    server_span: Span,
    shutdown: NotifyOnce,
) -> Result<(LxTask<()>, String)>
build_server_fut but additionally spawns the server future into an instrumented server task and logs the full URL used to access the server. Returns the server task and server url.