Module middleware

Module middleware 

Statics

POST_PROCESS_HEADER
The header name used for response post-processing signals.

Functions

check_content_length_header
Checks the CONTENT_LENGTH header and returns an early rejection if the contained value exceeds our configured body limit. This optimization allows us to avoid unnecessary work processing the request further.