pub struct LxBytes(pub Bytes);Expand description
A version of Bytes which conforms to Lexe’s (binary) API.
-
axumhas implementations ofFromRequestandIntoResponseforBytes, but these implementations are not Lexe API-conformant. -
This type can be used as either an extractor or a success response, and should always be used instead of
Bytesin these server contexts. -
It is still fine to use
Byteson the client side. -
As an extractor: rejections return
LxRejection. -
As a success response:
-
Returns an
http::Responsewith a binary body. -
Any failure encountered in extraction or creation should produce an
ErrorResponse.
-
The regular impls are non-conformant because:
- Rejections return
BytesRejectionwhich is just a string HTTP body.
NOTE: This must only be used for forming success API responses,
i.e. LxBytes in Result<LxBytes, E>, because its IntoResponse impl
uses StatusCode::OK. Our API error types are serialized as JSON and
have separate IntoResponse impls which return error statuses.
Tuple Fields
0: BytesTrait Implementations
Sourceimpl IntoResponse for LxBytes
The Bytes IntoResponse impl is almost exactly the same,
except it returns the wrong HTTP version.
impl IntoResponse for LxBytes
The Bytes IntoResponse impl is almost exactly the same,
except it returns the wrong HTTP version.
Sourcefn into_response(self) -> Response<Body>
fn into_response(self) -> Response<Body>
Sourceimpl Ord for LxBytes
impl Ord for LxBytes
Sourceimpl PartialOrd for LxBytes
impl PartialOrd for LxBytes
impl Eq for LxBytes
impl StructuralPartialEq for LxBytes