pub struct LxJson<T>(pub T);Expand description
A version of axum::Json which conforms to Lexe’s (JSON) API.
It can be used as either an extractor or a response.
- As an extractor: rejections return
LxRejection. - As a success response:
- Serialization success returns an
http::Responsewith JSON body. - Serialization failure returns a
ErrorResponse.
- Serialization success returns an
axum::Json is banned because:
- Rejections return
JsonRejectionwhich is just a string HTTP body. - Response serialization failures likewise return just a string body.
NOTE: This must only be used for forming success API responses,
i.e. T in Result<T, E>, because its IntoResponse impl uses
StatusCode::OK. Our API error types, while also serialized as JSON,
have separate IntoResponse impls which return error statuses.
Tuple Fields
0: TTrait Implementations
Sourceimpl<T: DeserializeOwned, S: Send + Sync> FromRequest<S> for LxJson<T>
impl<T: DeserializeOwned, S: Send + Sync> FromRequest<S> for LxJson<T>
Sourceimpl<T: Serialize> IntoResponse for LxJson<T>
impl<T: Serialize> IntoResponse for LxJson<T>
Sourcefn into_response(self) -> Response<Body>
fn into_response(self) -> Response<Body>
Create a response.
impl<T: Copy> Copy for LxJson<T>
impl<T: Eq + PartialEq> Eq for LxJson<T>