Module tls_acceptor

Module tls_acceptor 

TLS acceptor wrapper for injecting client certs into server-side handlers. TLS acceptor that injects the verified client certificate into request extensions after the TLS handshake completes successfully.

CertInjectorAcceptor wraps axum-server’s RustlsAcceptor to extract the client’s end-entity cert and inject it as VerifiedTlsClientCert.

Structs

CertInjectorAcceptor
An acceptor that wraps RustlsAcceptor to inject the verified client certificate into request extensions.
VerifiedTlsClientCert
The verified end-entity client certificate from an mTLS connection.