Module trace

Module trace 

API tracing utilities for both client and server. This module provides API tracing utilities for both client and server, including constants and fns which help keep client and server consistent.

Structs

TraceId
A TraceId identifies a tree of requests sharing a single causal source as it travels between different Lexe services.

Statics

GET_TRACE_ID_FN
A function pointer to a fn which attempts to extract a TraceId from the Extensions of the given span or any of its parents.
INSERT_TRACE_ID_FN
Like GET_TRACE_ID_FN, but inserts a TraceId into the Extensions of a given span, returning the replaced TraceId if it existed.