pub struct Invoice(pub Bolt11Invoice);Expand description
A BOLT 11 Lightning invoice. Serialized as a bech32-encoded string
(e.g. "lnbc1...").
Tuple Fields
0: Bolt11InvoiceImplementations
Sourceimpl Invoice
impl Invoice
Sourcepub fn payment_hash(&self) -> PaymentHash
pub fn payment_hash(&self) -> PaymentHash
The invoice payment hash. The payer will receive the preimage to this hash upon successful payment, as proof-of-payment.
Sourcepub fn payment_secret(&self) -> PaymentSecret
pub fn payment_secret(&self) -> PaymentSecret
The invoice payment secret, used to authenticate the payer to the payee and tie MPP HTLCs together.
Sourcepub fn payment_id(&self) -> PaymentId
pub fn payment_id(&self) -> PaymentId
Lexe’s main identifier for this payment, which for BOLT11 invoice
payments is just the Invoice::payment_hash.
pub fn network(&self) -> Network
pub fn supports_network(&self, network: Network) -> bool
Sourcepub fn description_str(&self) -> Option<&str>
pub fn description_str(&self) -> Option<&str>
If the invoice contains a non-empty, inline description, then return that as a string. Otherwise return None.
Sourcepub fn description_hash(&self) -> Option<&[u8; 32]>
pub fn description_hash(&self) -> Option<&[u8; 32]>
If the invoice uses a description hash, return that. Otherwise return None.
Sourcepub fn amount(&self) -> Option<Amount>
pub fn amount(&self) -> Option<Amount>
Return the invoice’s requested amount, if present. An invoice may leave the final amount up to the payer, in which case this field will be None.
Sourcepub fn amount_sats(&self) -> Option<u64>
pub fn amount_sats(&self) -> Option<u64>
The invoice amount in satoshis, if included.
Sourcepub fn created_at(&self) -> Result<TimestampMs, Error>
pub fn created_at(&self) -> Result<TimestampMs, Error>
Get the invoice creation timestamp. Returns an error if the timestamp is several hundred million years in the future.
Sourcepub fn saturating_created_at(&self) -> TimestampMs
pub fn saturating_created_at(&self) -> TimestampMs
Get the invoice creation timestamp unconditionally.
Sourcepub fn is_expired(&self) -> bool
pub fn is_expired(&self) -> bool
Returns true if the invoice has expired.
Sourcepub fn is_expired_at(&self, ts: TimestampMs) -> bool
pub fn is_expired_at(&self, ts: TimestampMs) -> bool
Returns true if the invoice expires before the given timestamp.
Sourcepub fn expires_at(&self) -> Result<TimestampMs, Error>
pub fn expires_at(&self) -> Result<TimestampMs, Error>
Get the invoice expiration timestamp. Returns an error if the timestamp is several hundred million years in the future.
Sourcepub fn saturating_expires_at(&self) -> TimestampMs
pub fn saturating_expires_at(&self) -> TimestampMs
Get the invoice expiration timestamp unconditionally.
Sourcepub fn payee_node_pk(&self) -> NodePk
pub fn payee_node_pk(&self) -> NodePk
Get the invoice payee’s NodePk.
If the pubkey is not included directly in the invoice, we have to
ecrecover the pubkey, which is somewhat more expensive (~20-40 us).
Sourcepub fn min_final_cltv_expiry_delta_u32(&self) -> Result<u32, Error>
pub fn min_final_cltv_expiry_delta_u32(&self) -> Result<u32, Error>
Returns the invoice’s min_final_cltv_expiry_delta time, if present,
otherwise lightning_invoice::DEFAULT_MIN_FINAL_CLTV_EXPIRY_DELTA.
Sourcepub fn onchain_fallbacks(&self) -> Vec<Address>
pub fn onchain_fallbacks(&self) -> Vec<Address>
BOLT11 Invoices can attach optional onchain addresses for a payee to use if the lightning payment is not feasible. This fn returns those addresses.
Sourcepub fn matches_hrp_prefix(s: &str) -> bool
pub fn matches_hrp_prefix(s: &str) -> bool
Returns true if the input string starts with a valid bech32 hrp prefix
for a BOLT11 invoice.