LnurlError

Struct LnurlError 

pub struct LnurlError {
    pub reason: String,
    pub status_code: StatusCode,
}
Error response for lnurl payment requests and callbacks.

Fields

reason: String

The error message to be diplayed to the payer.

status_code: StatusCode

Implementations

Source

impl LnurlError

pub fn bad_request(reason: impl Display) -> LnurlError

Constructs a LnurlError with a StatusCode::BAD_REQUEST.

pub fn server_error() -> LnurlError

Constructs a LnurlError with a StatusCode::INTERNAL_SERVER_ERROR. NOTE: This is used as the default error code for all errors that occur in the lnurl module in order to avoid leaking internal information to external clients.