LnurlPayRequest

Struct LnurlPayRequest 

pub struct LnurlPayRequest {
    pub callback: String,
    pub min_sendable: Amount,
    pub max_sendable: Amount,
    pub metadata: LnurlPayRequestMetadata,
    pub comment_allowed: Option<u16>,
}
The validated and parsed LNURL-pay request (“payRequest”).

This is the internal representation used throughout the codebase. For LUD-06 wire format serialization, use LnurlPayRequestWire.

Fields

callback: String

Callback URL to request invoice from.

min_sendable: Amount

Minimum sendable amount.

max_sendable: Amount

Maximum sendable amount.

metadata: LnurlPayRequestMetadata

Parsed metadata with description and description hash.

comment_allowed: Option<u16>

LUD-12: Max comment length in characters, if comments are supported.