pub struct PartnersInfo { /* private fields */ }Expand description
Information about Lexe partners, like the revshare schedule.
Implementations
Sourceimpl PartnersInfo
impl PartnersInfo
Return the partner’s proportional revshare of the payment fee given
the partner’s total proportional fee. Returns None if there is no
schedule with schedule_name.
This total is the effective proportional fee after partner_prop_fee
and partner_base_fee are both combined and taken into account, i.e.,
total_partner_fee := (partner_prop_fee * amount + partner_base_fee) / amount.
We don’t currently support a partner_base_fee for amountless invoices,
in which case total_partner_fee := partner_prop_fee.
Sourcepub fn current() -> PartnersInfo
pub fn current() -> PartnersInfo
The current partners info with the latest advertised revshare schedules.