PartnerFeeFields

Struct PartnerFeeFields 

pub struct PartnerFeeFields {
    pub user_pk: UserPk,
    pub prop_fee: Option<Ppm>,
    pub base_fee: Option<Amount>,
    pub revshare: Option<Decimal>,
}
Information about the partner fees for a specific payment.

The total fee is calculated as:

total_fee (sats) = base_fee + prop_fee * payment_value

Where payment_value is the “sticker price” of the payment:

  • Receives: payment_value := recvd_amount + skimmed_fee
  • Sends: payment_value := amount_sent

The partner’s revshare tier is determined by total_fee / payment_value, which is converted to a concrete partner revshare proportion based on the revshare schedule here: https://docs.lexe.tech/partner-fees/

Fields

user_pk: UserPk

The user_pk of the partner setting this fee.

prop_fee: Option<Ppm>

The partner-chosen proportional fee. Values of None are currently not allowed.

Minimum: 5000 ppm (LSP_USERNODE_SKIM_FEE_PPM) Maximum: 500,000 ppm (50%)

base_fee: Option<Amount>

The partner-chosen base fee.

This base fee can be set for outbound payments or inbound invoice payments with encoded payment amounts. Due to technical reasons, base fees cannot be set on amountless inbound invoices.

revshare: Option<Decimal>

The partner’s proportion of the total fee, expressed as a decimal.

Example: 0.8 represents an 80% partner share of total_fee.

Currently, only four values are allowed: [0.2, 0.5, 0.7, 0.8], but different revshare tiers may be adopted in the future.

For inbound payments, this is populated during PaymentClaimable.

Implementations

Source

impl PartnerFeeFields

pub fn validate(&self) -> Result<(), Error>

pub fn total_fee(&self, payment_value: Amount) -> Amount

total_fee := base_fee + prop_fee * payment_value