SealedSeed

Struct SealedSeed 

pub struct SealedSeed {
    pub id: SealedSeedId,
    pub ciphertext: Vec<u8>,
}
The user node’s provisioned seed that is sealed and persisted using its platform enclave keys that are software and version specific.

This struct is returned directly from the DB so it should be considered as untrusted and not-yet-validated.

See lexe_enclave::enclave::seal for more implementation details.

Fields

id: SealedSeedIdciphertext: Vec<u8>

The root seed, fully sealed + serialized.

Implementations

Source

impl SealedSeed

pub fn new( user_pk: UserPk, measurement: Measurement, machine_id: MachineId, ciphertext: Vec<u8>, ) -> SealedSeed

pub fn seal_from_root_seed<R>( rng: &mut R, root_seed: &RootSeed, deploy_env: DeployEnv, network: Network, measurement: Measurement, machine_id: MachineId, ) -> Result<SealedSeed, Error>
where R: Crng,

pub fn unseal_and_validate( self, expected_measurement: &Measurement, expected_machine_id: &MachineId, ) -> Result<(RootSeed, DeployEnv, Network), Error>