Empty

Struct Empty 

pub struct Empty {}
A struct denoting an empty API request or response.

This type should serialize/deserialize in such a way that we have room to add optional fields in the future without causing old clients to reject the message (backwards-compatible changes).

Always prefer this type over () (unit) to avoid API upgrade hazards. In JSON, unit will only deserialize from "null", meaning we can’t add new optional fields without breaking old clients.

assert_eq!("", serde_urlencoded::to_string(&Empty {}).unwrap());
assert_eq!("{}", serde_json::to_string(&Empty {}).unwrap());