Module vfs

Module vfs 

Make all of lexe_api_core available under [lexe_api].

NOTE: Any crates which can depend on lexe_api_core directly (without lexe-api) should do so to avoid [lexe_api] dependencies. Lexe’s VFS (“virtual file system”) trait and associated types. Virtual File System (‘vfs’)

Our “virtual file system” is a simple way to represent a key-value store with optional namespacing by “directory”. You can think of the vfs as a local directory that can contain files or directories, but where the directories cannot contain other directories (no nesting).

Any file can be uniquely identified by its <dirname>/<filename>, and all files exclusively contain only binary data Vec<u8>.

Singleton objects like the channel manager are stored in the global namespace, e.g. at ./channel_manager or ./bdk_wallet_db

Growable or shrinkable collections of objects (e.g. channel monitors), are stored in their own “directory”, e.g. channel_monitors/<funding_txo>.

Structs

MaybeVfsFile
An upgradeable version of Option<VfsFile>.
VecVfsFile
An upgradeable version of Vec<VfsFile>.
VecVfsFileId
An upgradeable version of Vec<VfsFileId>.
VfsDirectory
Uniquely identifies a directory in the virtual file system.
VfsDirectoryList
A list of all filenames within a VfsDirectory.
VfsFile
Represents a file in the virtual file system. The data field is almost always encrypted.
VfsFileId
Uniquely identifies a file in the virtual file system.

Constants

BROADCASTED_TXS_DIR
CHANNEL_MANAGER_FILENAME
CHANNEL_MONITORS_ARCHIVE_DIR
CHANNEL_MONITORS_DIR
EVENTS_DIR
MIGRATIONS_DIR
PW_ENC_ROOT_SEED_FILENAME
SINGLETON_DIRECTORY
The vfs directory name used by singleton objects.
UNSWEPT_OUTPUTS_EVENTS
UNSWEPT_OUTPUTS_TXS
WALLET_CHANGESET_LEGACY_FILENAME
WALLET_CHANGESET_V2_FILENAME

Statics

REVOCABLE_CLIENTS_FILE_ID

Traits

Vfs
Lexe’s async persistence interface.