BearerAuthenticator

Enum BearerAuthenticator 

pub enum BearerAuthenticator {
    Ephemeral {
        inner: EphemeralBearerAuthenticator,
    },
    Static {
        inner: StaticBearerAuthenticator,
    },
}
A BearerAuthenticator (1) stores existing fresh auth tokens and (2) authenticates and fetches new auth tokens when they expire.

Variants



Ephemeral

Fields

inner: EphemeralBearerAuthenticator


Static

Fields

inner: StaticBearerAuthenticator

Implementations

Source

impl BearerAuthenticator

pub fn new( user_key_pair: KeyPair, maybe_token: Option<TokenWithExpiration>, ) -> Self

Create a new BearerAuthenticator with the auth api handle, the user_key_pair (for signing auth requests), and an optional existing token.

pub fn new_with_scope( user_key_pair: KeyPair, maybe_token: Option<TokenWithExpiration>, scope: Option<Scope>, ) -> Self

BearerAuthenticator::new constructor with an optional scope to restrict requested auth tokens.

pub fn new_static_token(token: BearerAuthToken) -> Self

A BearerAuthenticator that always returns the same static, long-lived token.

pub fn user_key_pair(&self) -> Option<&KeyPair>

pub async fn get_token<T: BearerAuthBackendApi + ?Sized>( &self, api: &T, now: SystemTime, ) -> Result<BearerAuthToken, BackendApiError>

Try to either (1) return an existing, fresh token or (2) authenticate with the backend to get a new fresh token (and cache it).

pub async fn get_token_with_exp<T: BearerAuthBackendApi + ?Sized>( &self, api: &T, now: SystemTime, ) -> Result<TokenWithExpiration, BackendApiError>

Try to either (1) return an existing, fresh token or (2) authenticate with the backend to get a new fresh token (and cache it). Also returns the token’s expiration time.