pub trait AppBackendApi {
// Required methods
async fn signup_v2(
&self,
signed_req: &Signed<&UserSignupRequestWire>,
) -> Result<Empty, BackendApiError>;
async fn signup_v1(
&self,
signed_req: &Signed<&UserSignupRequestWireV1>,
) -> Result<Empty, BackendApiError>;
async fn enclaves_to_provision(
&self,
req: &EnclavesToProvisionRequest,
auth: BearerAuthToken,
) -> Result<EnclavesToProvision, BackendApiError>;
}Expand description
Defines the api that the backend exposes to the app (via the gateway).
Required Methods
Sourceasync fn signup_v2(
&self,
signed_req: &Signed<&UserSignupRequestWire>,
) -> Result<Empty, BackendApiError>
async fn signup_v2( &self, signed_req: &Signed<&UserSignupRequestWire>, ) -> Result<Empty, BackendApiError>
POST /app/v2/signup ed25519::Signed<UserSignupRequestWire> ->
Empty
Sourceasync fn signup_v1(
&self,
signed_req: &Signed<&UserSignupRequestWireV1>,
) -> Result<Empty, BackendApiError>
👎Deprecated: Use the signup_v2 API instead
async fn signup_v1( &self, signed_req: &Signed<&UserSignupRequestWireV1>, ) -> Result<Empty, BackendApiError>
Use the signup_v2 API instead
POST /app/v1/signup ed25519::Signed<UserSignupRequestWireV1> ->
Empty
Sourceasync fn enclaves_to_provision(
&self,
req: &EnclavesToProvisionRequest,
auth: BearerAuthToken,
) -> Result<EnclavesToProvision, BackendApiError>
async fn enclaves_to_provision( &self, req: &EnclavesToProvisionRequest, auth: BearerAuthToken, ) -> Result<EnclavesToProvision, BackendApiError>
Query which node enclaves the user needs to provision to.
POST /app/v1/enclaves_to_provision
EnclavesToProvisionRequest -> EnclavesToProvision
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.