Module command

Module command 

Request / response types used in APIs for top level commands.

Structs

BackupInfo
ClaimGeneratedHumanBitcoinAddress
Claims a generated human Bitcoin address.
CloseChannelRequest
CreateInvoiceRequest
CreateInvoiceResponse
CreateOfferRequest
CreateOfferResponse
DebugInfo
Diagnostic information for debugging purposes.
EnclavesToProvisionRequest
Request to query which node enclaves need provisioning, given the client’s trusted measurements.
FeeEstimate
GetAddressResponse
GetGeneratedUsernameResponse
Response for get_generated_username endpoint.
GetNewPayments
Sync a batch of new payments to local storage. Results are returned in ascending (created_at, payment_id) order.
GetUpdatedPaymentMetadata
Get a batch of payment metadata in asc (updated_at, payment_id) order.
GetUpdatedPayments
Get a batch of payments in ascending (updated_at, payment_id) order.
HumanBitcoinAddress
ListChannelsResponse
NodeInfo
Information about the Lexe node.
NodeInfoV1
OnchainDescriptors
BIP84 wpkh output descriptors for the on-chain wallet.
OpenChannelRequest
The information required for the user node to open a channel to the LSP.
OpenChannelResponse
PayInvoiceRequest
PayInvoiceResponse
PayOfferRequest
PayOfferResponse
PayOnchainRequest
PayOnchainResponse
PaymentCreatedIndexStruct
Upgradeable API struct for a payment index.
PaymentCreatedIndexes
Upgradeable API struct for a list of PaymentCreatedIndexs.
PaymentIdStruct
Upgradeable API struct for a PaymentId.
PreflightCloseChannelResponse
PreflightOpenChannelRequest
PreflightOpenChannelResponse
PreflightPayInvoiceRequest
PreflightPayInvoiceResponse
PreflightPayOfferRequest
PreflightPayOfferResponse
PreflightPayOnchainRequest
PreflightPayOnchainResponse
ResyncRequest
SetupGDrive
UpdateHumanBitcoinAddress
Creates or updates a human Bitcoin address.
UpdatePaymentNote
A request to update the personal note on a payment. Pass None to clear.
VecPaymentId
An upgradeable version of Vec<PaymentId>.

Enums

GDriveStatus

Type Aliases

PreflightCloseChannelRequest