pub struct OpenChannelRequest {
pub user_channel_id: LxUserChannelId,
pub value: Amount,
}Expand description
The information required for the user node to open a channel to the LSP.
Fields
user_channel_id: LxUserChannelIdA user-provided id for this channel that’s associated with the channel throughout its whole lifetime, as the Lightning protocol channel id is only known after negotiating the channel and creating the funding tx.
This id is also used for idempotency. Retrying a request with the same
user_channel_id won’t accidentally open another channel.
value: AmountThe value of the channel we want to open.