SetupGDrive

Struct SetupGDrive 

pub struct SetupGDrive {
    pub google_auth_code: String,
    pub encrypted_seed: Vec<u8>,
}

Fields

google_auth_code: String

The auth code which can used to obtain a set of GDrive credentials.

  • Applicable only in staging/prod.
  • If GDrive has not been setup, the node will acquire the full set of GDrive credentials and persist them (encrypted ofc) in Lexe’s DB.
encrypted_seed: Vec<u8>

The password-encrypted [RootSeed] which can be backed up in GDrive.

  • Applicable only in staging/prod.
  • If Drive backup is not setup, instance will back up this encrypted [RootSeed] in Google Drive. If a backup already exists, it is overwritten.
  • We require the client to password-encrypt prior to sending the provision request to prevent leaking the length of the password. It also shifts the burden of running the 600K HMAC iterations from the provision instance to the mobile app.