pub type PreflightCloseChannelRequest = CloseChannelRequest;Aliased Type
pub struct PreflightCloseChannelRequest {
pub channel_id: LxChannelId,
pub force_close: bool,
pub maybe_counterparty: Option<NodePk>,
}Fields
channel_id: LxChannelIdThe id of the channel we want to close.
force_close: boolSet to true if the channel should be force closed (unilateral). Set to false if the channel should be cooperatively closed (bilateral).
maybe_counterparty: Option<NodePk>