Make all of lexe_api_core available under [lexe_api].
NOTE: Any crates which can depend on lexe_api_core directly (without
lexe-api) should do so to avoid [lexe_api] dependencies.
Revocable client API types and RevocableClients.
Information about a client
Modules
- models
- Request and response types for the revocable client endpoints. Request and response types for the revocable client endpoints.
Structs
- Revocable
Client - Information about a revocable client.
Each client is issued a
RevocableClientCertwhose pubkey is saved here. - Revocable
Clients - All revocable clients which have ever been created.
- Revocable
Clients Handle - A locked
RevocableClients, newtyped so it can implementGetRevocableClientStatus. Share viaArc<RevocableClientsHandle>.