Statics
- POST_
PROCESS_ HEADER - The header name used for response post-processing signals.
Functions
- check_
content_ length_ header - Checks the
CONTENT_LENGTHheader and returns an early rejection if the contained value exceeds our configured body limit. This optimization allows us to avoid unnecessary work processing the request further.