TLS acceptor wrapper for injecting client certs into server-side handlers. TLS acceptor that injects the verified client certificate into request extensions after the TLS handshake completes successfully.
CertInjectorAcceptor wraps axum-server’s RustlsAcceptor to extract the
client’s end-entity cert and inject it as VerifiedTlsClientCert.
Structs
- Cert
Injector Acceptor - An acceptor that wraps
RustlsAcceptorto inject the verified client certificate into request extensions. - Verified
TlsClient Cert - The verified end-entity client certificate from an mTLS connection.