pub struct LnurlError {
pub reason: String,
pub status_code: StatusCode,
}Expand description
Error response for lnurl payment requests and callbacks.
Fields
reason: StringThe error message to be diplayed to the payer.
status_code: StatusCodeImplementations
Sourceimpl LnurlError
impl LnurlError
Sourcepub fn bad_request(reason: impl Display) -> LnurlError
pub fn bad_request(reason: impl Display) -> LnurlError
Constructs a LnurlError with a StatusCode::BAD_REQUEST.
Sourcepub fn server_error() -> LnurlError
pub fn server_error() -> LnurlError
Constructs a LnurlError with a
StatusCode::INTERNAL_SERVER_ERROR.
NOTE: This is used as the default error code for all errors that occur
in the lnurl module in order to avoid leaking internal information
to external clients.