LnurlPayRequestMetadata

Struct LnurlPayRequestMetadata 

pub struct LnurlPayRequestMetadata {
    pub description: String,
    pub long_description: Option<String>,
    pub image_png_base64: Option<String>,
    pub image_jpeg_base64: Option<String>,
    pub identifier: Option<String>,
    pub email: Option<String>,
    pub description_hash: [u8; 32],
    pub raw: String,
}
The metadata inside a LnurlPayRequest.

Fields

description: String

Short description from text/plain (required, LUD-06).

long_description: Option<String>

Long description from text/long-desc (optional, LUD-06). Can be displayed to the user when prompting the user for an amount.

image_png_base64: Option<String>

PNG thumbnail from image/png;base64 (optional, LUD-06). Can be displayed to the user when prompting the user for an amount.

image_jpeg_base64: Option<String>

JPEG thumbnail from image/jpeg;base64 (optional, LUD-06). Can be displayed to the user when prompting the user for an amount.

identifier: Option<String>

Internet identifier from text/identifier (LUD-16). LNURL-Pay via LUD-16 requires this or text/email to be set.

email: Option<String>

Email address from text/email (LUD-16). LNURL-Pay via LUD-16 requires this or text/identifier to be set.

description_hash: [u8; 32]

SHA256 hash of raw metadata for invoice validation.

raw: String

The original unparsed metadata string.

Implementations

Source

impl LnurlPayRequestMetadata

pub fn from_email(email: &str) -> LnurlPayRequestMetadata

pub fn from_raw_string(raw: String) -> Result<LnurlPayRequestMetadata, Error>

Parses LNURL-pay metadata string into structured metadata.

LUD-06 metadata field is a JSON array encoded as a string: "[[\"text/plain\", \"lorem ipsum blah blah\"]]".

pub fn to_raw_string(&self) -> String

Serializes the metadata back into the raw LNURL-pay metadata string.

Generates a JSON array encoded as a string, suitable for use in LNURL-pay requests. The order of entries is deterministic.