#[repr(transparent)]pub struct MaxQuantity(pub NonZero<u64>);Expand description
The max number of items that can be purchased in one payment with the offer.
The expected amount paid for this offer is offer.amount * quantity,
where offer.amount is the amount per item and quantity is the
number of items chosen by the payer. The payer’s chosen quantity must be
in the range: 0 < quantity <= offer.max_quantity.
NOTE: this is NOT related to reusable vs single-use offers.
This type is effectively LDK’s Quantity type but serde serializable. We
also use u64::MAX to represent “unbounded” quantity. This makes the
CreateOfferRequest serialization simpler, since max_quantity should be
an optional field and Option<Option<NonZeroU64>> has a strange
serialization.
See: CreateOfferRequest::max_quantity.
Tuple Fields
0: NonZero<u64>Implementations
Sourceimpl MaxQuantity
impl MaxQuantity
pub const ONE: MaxQuantity
pub const UNBOUNDED: MaxQuantity